pub struct MLKEM<const PK_LEN: usize, const SK_LEN: usize, const FULL_SK_LEN: usize, const CT_LEN: usize, const SS_LEN: usize, PK: MLKEMPublicKeyTrait<k, PK_LEN, T_PACKED_LEN> + MLKEMPublicKeyInternalTrait<k, T_PACKED_LEN, PK_LEN>, SK: MLKEMPrivateKeyTrait<k, SK_LEN, FULL_SK_LEN, PK_LEN, T_PACKED_LEN> + MLKEMPrivateKeyInternalTrait<k, SK_LEN, PK_LEN, T_PACKED_LEN>, const k: usize, const eta1: i16, const du: i16, const dv: i16, const LAMBDA: i16, const T_PACKED_LEN: usize> { /* private fields */ }Expand description
The core internal implementation of the ML-KEM algorithm. This needs to be public for the compiler to be able to find it, but you shouldn’t ever need to use this directly. Please use the named public types.
Implementations
Sourceimpl<const PK_LEN: usize, const SK_LEN: usize, const FULL_SK_LEN: usize, const CT_LEN: usize, const SS_LEN: usize, PK: MLKEMPublicKeyTrait<k, PK_LEN, T_PACKED_LEN> + MLKEMPublicKeyInternalTrait<k, T_PACKED_LEN, PK_LEN>, SK: MLKEMPrivateKeyTrait<k, SK_LEN, FULL_SK_LEN, PK_LEN, T_PACKED_LEN> + MLKEMPrivateKeyInternalTrait<k, SK_LEN, PK_LEN, T_PACKED_LEN>, const k: usize, const eta1: i16, const du: i16, const dv: i16, const LAMBDA: i16, const T_PACKED_LEN: usize> MLKEM<PK_LEN, SK_LEN, FULL_SK_LEN, CT_LEN, SS_LEN, PK, SK, k, eta1, du, dv, LAMBDA, T_PACKED_LEN>
impl<const PK_LEN: usize, const SK_LEN: usize, const FULL_SK_LEN: usize, const CT_LEN: usize, const SS_LEN: usize, PK: MLKEMPublicKeyTrait<k, PK_LEN, T_PACKED_LEN> + MLKEMPublicKeyInternalTrait<k, T_PACKED_LEN, PK_LEN>, SK: MLKEMPrivateKeyTrait<k, SK_LEN, FULL_SK_LEN, PK_LEN, T_PACKED_LEN> + MLKEMPrivateKeyInternalTrait<k, SK_LEN, PK_LEN, T_PACKED_LEN>, const k: usize, const eta1: i16, const du: i16, const dv: i16, const LAMBDA: i16, const T_PACKED_LEN: usize> MLKEM<PK_LEN, SK_LEN, FULL_SK_LEN, CT_LEN, SS_LEN, PK, SK, k, eta1, du, dv, LAMBDA, T_PACKED_LEN>
Sourcepub fn keygen_from_os_rng() -> Result<(PK, SK), KEMError>
pub fn keygen_from_os_rng() -> Result<(PK, SK), KEMError>
Should still be ok in FIPS mode
Sourcepub fn encaps_internal(ek: &PK, m: [u8; 32]) -> ([u8; 32], [u8; CT_LEN])
pub fn encaps_internal(ek: &PK, m: [u8; 32]) -> ([u8; 32], [u8; CT_LEN])
Algorithm 17 ML-KEM.Encaps_internal(ek, 𝑚) Uses the encapsulation key and randomness to generate a key and an associated ciphertext. Input: encapsulation key ek ∈ 𝔹384𝑘+32 . Input: randomness 𝑚 ∈ 𝔹32 . Output: shared secret key 𝐾 ∈ 𝔹32 . Output: ciphertext 𝑐 ∈ 𝔹32(𝑑𝑢𝑘+𝑑𝑣).
Unlike the more public function exposed by KEM::encaps, this returns the shared secret as raw bytes instead of wrapped in an appropriately-set KeyMaterialTrait, so you’re on your own for handling it properly.
Note: this is an internal function that allows the caller to specify the encapsulation
randomness (which is the message m to be encrypted by the underlying PKE scheme).
This function should not be used directly unless you really have a
good reason. KEM::encaps should be used in 99.9% of cases.
The reason this is exposed publicly is: A) for unit testing that requires access
to the deterministically reproducible function, and B) for operational environments
that wish to provide randomness from their own source instead of the built-in RNG in bc-rust.
If you think you will be clever and invent some scheme that uses a deterministic KEM,
then you will almost certainly end up with security problems. Please don’t do this.
Sourcepub fn decaps_from_seed(
seed: &KeyMaterial<64>,
ct: &[u8],
) -> Result<KeyMaterial<SS_LEN>, KEMError>
pub fn decaps_from_seed( seed: &KeyMaterial<64>, ct: &[u8], ) -> Result<KeyMaterial<SS_LEN>, KEMError>
Alternative initialization of the streaming signer where you have your private key as a seed and you want to delay its expansion as late as possible for memory-usage reasons.