pub type MLKEM1024 = MLKEM<MLKEM1024_PK_LEN, MLKEM1024_SK_LEN, MLKEM1024_FULL_SK_LEN, MLKEM1024_CT_LEN, MLKEM_SS_LEN, MLKEM1024PublicKey, MLKEM1024PrivateKey, MLKEM1024_k, MLKEM1024_ETA1, MLKEM1024_DU, MLKEM1024_DV, MLKEM1024_LAMBDA, MLKEM1024_T_PACKED_LEN>;Expand description
The ML-KEM-1024 algorithm.
Aliased Type
pub struct MLKEM1024 { /* private fields */ }Trait Implementations
Sourceimpl Algorithm for MLKEM1024
impl Algorithm for MLKEM1024
Sourceconst ALG_NAME: &'static str = ML_KEM_1024_NAME
const ALG_NAME: &'static str = ML_KEM_1024_NAME
String name for the algorithm, used consistently across the library.
Sourceconst MAX_SECURITY_STRENGTH: SecurityStrength = SecurityStrength::_256bit
const MAX_SECURITY_STRENGTH: SecurityStrength = SecurityStrength::_256bit
Maximum security strength supported by the algorithm.
In other words, this algorithm can produce outputs up to this security strength,
but may produce outputs with lower security strength, for example, if asked to truncate.