pub type MLKEM512 = MLKEM<MLKEM512_PK_LEN, MLKEM512_SK_LEN, MLKEM512_FULL_SK_LEN, MLKEM512_CT_LEN, MLKEM_SS_LEN, MLKEM512PublicKey, MLKEM512PrivateKey, MLKEM512_k, MLKEM512_ETA1, MLKEM512_DU, MLKEM512_DV, MLKEM512_LAMBDA, MLKEM512_T_PACKED_LEN>;Expand description
The ML-KEM-512 algorithm.
Aliased Type
pub struct MLKEM512 { /* private fields */ }Trait Implementations
Sourceimpl Algorithm for MLKEM512
impl Algorithm for MLKEM512
Sourceconst ALG_NAME: &'static str = ML_KEM_512_NAME
const ALG_NAME: &'static str = ML_KEM_512_NAME
String name for the algorithm, used consistently across the library.
Sourceconst MAX_SECURITY_STRENGTH: SecurityStrength = SecurityStrength::_128bit
const MAX_SECURITY_STRENGTH: SecurityStrength = SecurityStrength::_128bit
Maximum security strength supported by the algorithm.
In other words, this algorithm can produce outputs up to this security strength,
but may produce outputs with lower security strength, for example, if asked to truncate.